[nautilus-actions] NactTreeView class is renamed to FMATreeView



commit 89d71a6d938bb6b78dac954443054a297f37a9e5
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 20:48:00 2015 +0200

    NactTreeView class is renamed to FMATreeView

 src/ui/Makefile.am                           |    4 +-
 src/ui/fma-assistant-export.c                |   20 +-
 src/ui/fma-assistant-import.c                |    6 +-
 src/ui/fma-clipboard.c                       |    2 +-
 src/ui/fma-clipboard.h                       |    2 +-
 src/ui/fma-iaction-tab.c                     |    8 +-
 src/ui/fma-ibasenames-tab.c                  |    6 +-
 src/ui/fma-icapabilities-tab.c               |    6 +-
 src/ui/fma-icommand-tab.c                    |    6 +-
 src/ui/fma-ienvironment-tab.c                |    6 +-
 src/ui/fma-iexecution-tab.c                  |    6 +-
 src/ui/fma-ifolders-tab.c                    |    6 +-
 src/ui/fma-imimetypes-tab.c                  |    6 +-
 src/ui/fma-iproperties-tab.c                 |    6 +-
 src/ui/fma-ischemes-tab.c                    |    6 +-
 src/ui/fma-main-window.c                     |   26 +-
 src/ui/fma-main-window.h                     |    4 +-
 src/ui/fma-match-list.c                      |    8 +-
 src/ui/fma-menu-edit.c                       |   12 +-
 src/ui/fma-menu-file.c                       |   12 +-
 src/ui/fma-menu.c                            |   36 ++--
 src/ui/fma-sort-buttons.c                    |    8 +-
 src/ui/fma-tree-ieditable.c                  |   38 ++--
 src/ui/fma-tree-ieditable.h                  |    2 +-
 src/ui/fma-tree-model-dnd.c                  |    8 +-
 src/ui/{nact-tree-view.c => fma-tree-view.c} |  308 +++++++++++++-------------
 src/ui/{nact-tree-view.h => fma-tree-view.h} |   68 +++---
 27 files changed, 313 insertions(+), 313 deletions(-)
---
diff --git a/src/ui/Makefile.am b/src/ui/Makefile.am
index 63e7f23..019ce74 100644
--- a/src/ui/Makefile.am
+++ b/src/ui/Makefile.am
@@ -138,8 +138,8 @@ fma_config_tool_SOURCES = \
        fma-tree-model.h                                                                        \
        fma-tree-model-priv.h                                                           \
        fma-tree-model-dnd.c                                                            \
-       nact-tree-view.c                                                                        \
-       nact-tree-view.h                                                                        \
+       fma-tree-view.c                                                                 \
+       fma-tree-view.h                                                                 \
        $(BUILT_SOURCES)                                                                        \
        $(NULL)
 
diff --git a/src/ui/fma-assistant-import.c b/src/ui/fma-assistant-import.c
index 786ab1b..fe5f8ee 100644
--- a/src/ui/fma-assistant-import.c
+++ b/src/ui/fma-assistant-import.c
@@ -650,7 +650,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
        FMAImporterResult *result;
        FMAApplication *application;
        FMAUpdater *updater;
-       NactTreeView *items_view;
+       FMATreeView *items_view;
 
        g_return_if_fail( FMA_IS_ASSISTANT_IMPORT( wnd ));
 
@@ -716,7 +716,7 @@ static FMAObjectItem *
 check_for_existence( const FMAObjectItem *item, FMAMainWindow *window )
 {
        static const gchar *thisfn = "fma_assistant_import_check_for_existence";
-       NactTreeView *items_view;
+       FMATreeView *items_view;
        FMAObjectItem *exists;
        gchar *importing_id;
 
@@ -725,7 +725,7 @@ check_for_existence( const FMAObjectItem *item, FMAMainWindow *window )
                        thisfn, ( void * ) item, G_OBJECT_TYPE_NAME( item ), importing_id );
 
        items_view = fma_main_window_get_items_view( window );
-       exists = nact_tree_view_get_item_by_id( items_view, importing_id );
+       exists = fma_tree_view_get_item_by_id( items_view, importing_id );
 
        g_free( importing_id );
 
diff --git a/src/ui/fma-clipboard.c b/src/ui/fma-clipboard.c
index 4a0c12b..6d9cb4b 100644
--- a/src/ui/fma-clipboard.c
+++ b/src/ui/fma-clipboard.c
@@ -346,7 +346,7 @@ fma_clipboard_dnd_get_data( FMAClipboard *clipboard, gboolean *copy_data )
                if( selection ){
                        data = ( FMAClipboardDndData * ) gtk_selection_data_get_data( selection );
 
-                       if( data->target == FMA_XCHANGE_FORMAT_NACT ){
+                       if( data->target == FMA_XCHANGE_FORMAT_FMA ){
                                for( it = data->rows ; it ; it = it->next ){
                                        rows = g_list_append( rows,
                                                        gtk_tree_row_reference_copy(( GtkTreeRowReference * ) 
it->data ));
diff --git a/src/ui/fma-clipboard.h b/src/ui/fma-clipboard.h
index 9809754..ad6c478 100644
--- a/src/ui/fma-clipboard.h
+++ b/src/ui/fma-clipboard.h
@@ -74,7 +74,7 @@ typedef struct {
 /* drag and drop formats
  */
 enum {
-       FMA_XCHANGE_FORMAT_NACT = 0,
+       FMA_XCHANGE_FORMAT_FMA = 0,
        FMA_XCHANGE_FORMAT_XDS,
        FMA_XCHANGE_FORMAT_APPLICATION_XML,
        FMA_XCHANGE_FORMAT_TEXT_PLAIN,
diff --git a/src/ui/fma-iaction-tab.c b/src/ui/fma-iaction-tab.c
index 44fdd8b..454ab2e 100644
--- a/src/ui/fma-iaction-tab.c
+++ b/src/ui/fma-iaction-tab.c
@@ -47,7 +47,7 @@
 #include "fma-main-window.h"
 #include "fma-iaction-tab.h"
 #include "fma-icon-chooser.h"
-#include "nact-tree-view.h"
+#include "fma-tree-view.h"
 
 /* private interface data
  */
@@ -76,7 +76,7 @@ static void         interface_base_finalize( FMAIActionTabInterface *klass );
 static void         initialize_gtk( FMAIActionTab *instance );
 static void         initialize_window( FMAIActionTab *instance );
 static void         on_main_item_updated( FMAIActionTab *instance, FMAIContext *context, guint data, void 
*empty );
-static void         on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIActionTab 
*instance );
+static void         on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAIActionTab 
*instance );
 static void         on_target_selection_toggled( GtkToggleButton *button, FMAIActionTab *instance );
 static void         on_target_location_toggled( GtkToggleButton *button, FMAIActionTab *instance );
 static void         check_for_label( FMAIActionTab *instance, GtkEntry *entry, const gchar *label );
@@ -234,7 +234,7 @@ static void
 initialize_window( FMAIActionTab *instance )
 {
        static const gchar *thisfn = "fma_iaction_tab_initialize_window";
-       NactTreeView *tview;
+       FMATreeView *tview;
 
        g_return_if_fail( FMA_IS_IACTION_TAB( instance ));
 
@@ -330,7 +330,7 @@ on_main_item_updated( FMAIActionTab *instance, FMAIContext *context, guint data,
 }
 
 static void
-on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIActionTab *instance )
+on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAIActionTab *instance )
 {
        static const gchar *thisfn = "fma_iaction_tab_on_tree_selection_changed";
        guint count_selected;
diff --git a/src/ui/fma-ibasenames-tab.c b/src/ui/fma-ibasenames-tab.c
index e53f25f..17ccd37 100644
--- a/src/ui/fma-ibasenames-tab.c
+++ b/src/ui/fma-ibasenames-tab.c
@@ -69,7 +69,7 @@ static void            interface_base_init( FMAIBasenamesTabInterface *klass );
 static void            interface_base_finalize( FMAIBasenamesTabInterface *klass );
 static void            initialize_gtk( FMAIBasenamesTab *instance );
 static void            initialize_window( FMAIBasenamesTab *instance );
-static void            on_tree_selection_changed( NactTreeView *tview, GList *selected_items, 
FMAIBasenamesTab *instance );
+static void            on_tree_selection_changed( FMATreeView *tview, GList *selected_items, 
FMAIBasenamesTab *instance );
 static void            on_matchcase_toggled( GtkToggleButton *button, FMAIBasenamesTab *instance );
 static GSList         *get_basenames( void *context );
 static void            set_basenames( void *context, GSList *filters );
@@ -217,7 +217,7 @@ static void
 initialize_window( FMAIBasenamesTab *instance )
 {
        static const gchar *thisfn = "fma_ibasenames_tab_initialize_window";
-       NactTreeView *tview;
+       FMATreeView *tview;
 
        g_return_if_fail( instance && FMA_IS_IBASENAMES_TAB( instance ));
 
@@ -235,7 +235,7 @@ initialize_window( FMAIBasenamesTab *instance )
 }
 
 static void
-on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIBasenamesTab *instance )
+on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAIBasenamesTab *instance )
 {
        FMAIContext *context;
        gboolean editable;
diff --git a/src/ui/fma-icapabilities-tab.c b/src/ui/fma-icapabilities-tab.c
index 265a259..17262e3 100644
--- a/src/ui/fma-icapabilities-tab.c
+++ b/src/ui/fma-icapabilities-tab.c
@@ -59,7 +59,7 @@ static void    interface_base_init( FMAICapabilitiesTabInterface *klass );
 static void    interface_base_finalize( FMAICapabilitiesTabInterface *klass );
 static void    initialize_gtk( FMAICapabilitiesTab *instance );
 static void    initialize_window( FMAICapabilitiesTab *instance );
-static void    on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAICapabilitiesTab 
*instance );
+static void    on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAICapabilitiesTab 
*instance );
 static void    on_add_clicked( GtkButton *button, FMAICapabilitiesTab *instance );
 static GSList *get_capabilities( FMAIContext *context );
 static void    set_capabilities( FMAIContext *context, GSList *list );
@@ -189,7 +189,7 @@ static void
 initialize_window( FMAICapabilitiesTab *instance )
 {
        static const gchar *thisfn = "fma_icapabilities_tab_initialize_window";
-       NactTreeView *tview;
+       FMATreeView *tview;
 
        g_return_if_fail( FMA_IS_ICAPABILITIES_TAB( instance ));
 
@@ -204,7 +204,7 @@ initialize_window( FMAICapabilitiesTab *instance )
 }
 
 static void
-on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAICapabilitiesTab *instance )
+on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAICapabilitiesTab *instance )
 {
        FMAIContext *context;
        gboolean editable;
diff --git a/src/ui/fma-icommand-tab.c b/src/ui/fma-icommand-tab.c
index 44a8efd..94bfaf8 100644
--- a/src/ui/fma-icommand-tab.c
+++ b/src/ui/fma-icommand-tab.c
@@ -78,7 +78,7 @@ static void          interface_base_finalize( FMAICommandTabInterface *klass );
 static void          initialize_gtk( FMAICommandTab *instance );
 static void          initialize_window( FMAICommandTab *instance );
 static void          on_main_item_updated( FMAICommandTab *instance, FMAIContext *context, guint data, void 
*empty );
-static void          on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAICommandTab 
*instance );
+static void          on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAICommandTab 
*instance );
 static GtkWidget    *get_label_entry( FMAICommandTab *instance );
 static GtkButton    *get_legend_button( FMAICommandTab *instance );
 static GtkWindow    *get_legend_dialog( FMAICommandTab *instance );
@@ -221,7 +221,7 @@ initialize_window( FMAICommandTab *instance )
        GtkWidget *label_entry, *path_entry, *parameters_entry;
        GtkButton *legend_button, *path_button;
        ICommandData *data;
-       NactTreeView *tview;
+       FMATreeView *tview;
 
        g_return_if_fail( FMA_IS_ICOMMAND_TAB( instance ));
 
@@ -305,7 +305,7 @@ on_main_item_updated( FMAICommandTab *instance, FMAIContext *context, guint data
 }
 
 static void
-on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAICommandTab *instance )
+on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAICommandTab *instance )
 {
        static const gchar *thisfn = "fma_icommand_tab_on_tree_selection_changed";
        FMAObjectProfile *profile;
diff --git a/src/ui/fma-ienvironment-tab.c b/src/ui/fma-ienvironment-tab.c
index 8067b66..ed34641 100644
--- a/src/ui/fma-ienvironment-tab.c
+++ b/src/ui/fma-ienvironment-tab.c
@@ -101,7 +101,7 @@ static void          interface_base_init( FMAIEnvironmentTabInterface *klass );
 static void          interface_base_finalize( FMAIEnvironmentTabInterface *klass );
 static void          initialize_gtk( FMAIEnvironmentTab *instance );
 static void          initialize_window( FMAIEnvironmentTab *instance );
-static void          on_tree_selection_changed( NactTreeView *tview, GList *selected_items, 
FMAIEnvironmentTab *instance );
+static void          on_tree_selection_changed( FMATreeView *tview, GList *selected_items, 
FMAIEnvironmentTab *instance );
 static void          on_selcount_ope_changed( GtkComboBox *combo, FMAIEnvironmentTab *instance );
 static void          on_selcount_int_changed( GtkEntry *entry, FMAIEnvironmentTab *instance );
 static void          on_selection_count_changed( FMAIEnvironmentTab *instance );
@@ -262,7 +262,7 @@ initialize_window( FMAIEnvironmentTab *instance )
        GList *renderers;
        guint i;
        const FMADesktopEnv *desktops;
-       NactTreeView *tview;
+       FMATreeView *tview;
 
        g_return_if_fail( FMA_IS_IENVIRONMENT_TAB( instance ));
 
@@ -346,7 +346,7 @@ initialize_window( FMAIEnvironmentTab *instance )
 }
 
 static void
-on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIEnvironmentTab *instance )
+on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAIEnvironmentTab *instance )
 {
        static const gchar *thisfn = "fma_ienvironment_tab_on_tree_selection_changed";
        FMAIContext *context;
diff --git a/src/ui/fma-iexecution-tab.c b/src/ui/fma-iexecution-tab.c
index 17bf56c..5d58826 100644
--- a/src/ui/fma-iexecution-tab.c
+++ b/src/ui/fma-iexecution-tab.c
@@ -63,7 +63,7 @@ static GType           register_type( void );
 static void            interface_base_init( FMAIExecutionTabInterface *klass );
 static void            interface_base_finalize( FMAIExecutionTabInterface *klass );
 static void            initialize_window( FMAIExecutionTab *instance );
-static void            on_tree_selection_changed( NactTreeView *tview, GList *selected_items, 
FMAIExecutionTab *instance );
+static void            on_tree_selection_changed( FMATreeView *tview, GList *selected_items, 
FMAIExecutionTab *instance );
 static void            on_normal_mode_toggled( GtkToggleButton *togglebutton, FMAIExecutionTab *instance );
 static void            on_terminal_mode_toggled( GtkToggleButton *togglebutton, FMAIExecutionTab *instance );
 static void            on_embedded_mode_toggled( GtkToggleButton *togglebutton, FMAIExecutionTab *instance );
@@ -183,7 +183,7 @@ static void
 initialize_window( FMAIExecutionTab *instance )
 {
        static const gchar *thisfn = "fma_iexecution_tab_initialize_window";
-       NactTreeView *tview;
+       FMATreeView *tview;
 
        g_return_if_fail( FMA_IS_IEXECUTION_TAB( instance ));
 
@@ -226,7 +226,7 @@ initialize_window( FMAIExecutionTab *instance )
 }
 
 static void
-on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIExecutionTab *instance )
+on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAIExecutionTab *instance )
 {
        static const gchar *thisfn = "fma_iexecution_tab_on_tree_selection_changed";
        FMAObjectProfile *profile;
diff --git a/src/ui/fma-ifolders-tab.c b/src/ui/fma-ifolders-tab.c
index 95a0d9d..4ef39e7 100644
--- a/src/ui/fma-ifolders-tab.c
+++ b/src/ui/fma-ifolders-tab.c
@@ -63,7 +63,7 @@ static void    interface_base_init( FMAIFoldersTabInterface *klass );
 static void    interface_base_finalize( FMAIFoldersTabInterface *klass );
 static void    initialize_gtk( FMAIFoldersTab *instance );
 static void    initialize_window( FMAIFoldersTab *instance );
-static void    on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIFoldersTab 
*instance );
+static void    on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAIFoldersTab 
*instance );
 static void    on_browse_folder_clicked( GtkButton *button, FMAIFoldersTab *instance );
 static GSList *get_folders( void *context );
 static void    set_folders( void *context, GSList *filters );
@@ -193,7 +193,7 @@ static void
 initialize_window( FMAIFoldersTab *instance )
 {
        static const gchar *thisfn = "fma_ifolders_tab_initialize_window";
-       NactTreeView *tview;
+       FMATreeView *tview;
 
        g_return_if_fail( FMA_IS_IFOLDERS_TAB( instance ));
 
@@ -212,7 +212,7 @@ initialize_window( FMAIFoldersTab *instance )
 }
 
 static void
-on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIFoldersTab *instance )
+on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAIFoldersTab *instance )
 {
        FMAIContext *context;
        gboolean editable;
diff --git a/src/ui/fma-imimetypes-tab.c b/src/ui/fma-imimetypes-tab.c
index 6b649e2..84e7f22 100644
--- a/src/ui/fma-imimetypes-tab.c
+++ b/src/ui/fma-imimetypes-tab.c
@@ -59,7 +59,7 @@ static void    interface_base_init( FMAIMimetypesTabInterface *klass );
 static void    interface_base_finalize( FMAIMimetypesTabInterface *klass );
 static void    initialize_gtk( FMAIMimetypesTab *instance );
 static void    initialize_window( FMAIMimetypesTab *instance );
-static void    on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIMimetypesTab 
*instance );
+static void    on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAIMimetypesTab 
*instance );
 static GSList *get_mimetypes( void *context );
 static void    set_mimetypes( void *context, GSList *filters );
 static void    on_instance_finalized( gpointer user_data, FMAIMimetypesTab *instance );
@@ -201,7 +201,7 @@ static void
 initialize_window( FMAIMimetypesTab *instance )
 {
        static const gchar *thisfn = "fma_imimetypes_tab_initialize_window";
-       NactTreeView *tview;
+       FMATreeView *tview;
 
        g_return_if_fail( FMA_IS_IMIMETYPES_TAB( instance ));
 
@@ -216,7 +216,7 @@ initialize_window( FMAIMimetypesTab *instance )
 }
 
 static void
-on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIMimetypesTab *instance )
+on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAIMimetypesTab *instance )
 {
        FMAIContext *context;
        gboolean editable;
diff --git a/src/ui/fma-iproperties-tab.c b/src/ui/fma-iproperties-tab.c
index 6ce0e7a..6046162 100644
--- a/src/ui/fma-iproperties-tab.c
+++ b/src/ui/fma-iproperties-tab.c
@@ -69,7 +69,7 @@ static GType            register_type( void );
 static void             interface_base_init( FMAIPropertiesTabInterface *klass );
 static void             interface_base_finalize( FMAIPropertiesTabInterface *klass );
 static void             initialize_window( FMAIPropertiesTab *instance );
-static void             on_tree_selection_changed( NactTreeView *tview, GList *selected_items, 
FMAIPropertiesTab *instance );
+static void             on_tree_selection_changed( FMATreeView *tview, GList *selected_items, 
FMAIPropertiesTab *instance );
 static void             on_main_item_updated( FMAIPropertiesTab *instance, FMAIContext *context, guint data, 
void *empty );
 static GtkButton       *get_enabled_button( FMAIPropertiesTab *instance );
 static void             on_enabled_toggled( GtkToggleButton *button, FMAIPropertiesTab *instance );
@@ -184,7 +184,7 @@ initialize_window( FMAIPropertiesTab *instance )
        GtkButton *enabled_button;
        GtkWidget *label_widget;
        GtkTextBuffer *buffer;
-       NactTreeView *tview;
+       FMATreeView *tview;
 
        g_return_if_fail( FMA_IS_IPROPERTIES_TAB( instance ));
 
@@ -220,7 +220,7 @@ initialize_window( FMAIPropertiesTab *instance )
 }
 
 static void
-on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAIPropertiesTab *instance )
+on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAIPropertiesTab *instance )
 {
        static const gchar *thisfn = "fma_iproperties_tab_on_tree_selection_changed";
        guint count_selected;
diff --git a/src/ui/fma-ischemes-tab.c b/src/ui/fma-ischemes-tab.c
index 13cebdb..7f74931 100644
--- a/src/ui/fma-ischemes-tab.c
+++ b/src/ui/fma-ischemes-tab.c
@@ -62,7 +62,7 @@ static void    interface_base_init( FMAISchemesTabInterface *klass );
 static void    interface_base_finalize( FMAISchemesTabInterface *klass );
 static void    initialize_gtk( FMAISchemesTab *instance );
 static void    initialize_window( FMAISchemesTab *instance );
-static void    on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAISchemesTab 
*instance );
+static void    on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAISchemesTab 
*instance );
 static void    on_add_from_defaults( GtkButton *button, FMAISchemesTab *instance );
 static GSList *get_schemes( void *context );
 static void    set_schemes( void *context, GSList *filters );
@@ -192,7 +192,7 @@ static void
 initialize_window( FMAISchemesTab *instance )
 {
        static const gchar *thisfn = "fma_ischemes_tab_initialize_window";
-       NactTreeView *tview;
+       FMATreeView *tview;
 
        g_return_if_fail( FMA_IS_ISCHEMES_TAB( instance ));
 
@@ -211,7 +211,7 @@ initialize_window( FMAISchemesTab *instance )
 }
 
 static void
-on_tree_selection_changed( NactTreeView *tview, GList *selected_items, FMAISchemesTab *instance )
+on_tree_selection_changed( FMATreeView *tview, GList *selected_items, FMAISchemesTab *instance )
 {
        FMAIContext *context;
        gboolean editable;
diff --git a/src/ui/fma-main-window.h b/src/ui/fma-main-window.h
index 81ef83d..8a86ddd 100644
--- a/src/ui/fma-main-window.h
+++ b/src/ui/fma-main-window.h
@@ -42,7 +42,7 @@
 #include "fma-main-window-def.h"
 #include "fma-sort-buttons.h"
 #include "fma-status-bar.h"
-#include "nact-tree-view.h"
+#include "fma-tree-view.h"
 
 G_BEGIN_DECLS
 
@@ -79,7 +79,7 @@ FMASortButtons *fma_main_window_get_sort_buttons( const FMAMainWindow *window );
 
 FMAStatusBar   *fma_main_window_get_statusbar   ( const FMAMainWindow *window );
 
-NactTreeView    *fma_main_window_get_items_view  ( const FMAMainWindow *window );
+FMATreeView    *fma_main_window_get_items_view  ( const FMAMainWindow *window );
 
 void            fma_main_window_reload          ( FMAMainWindow *window );
 
diff --git a/src/ui/fma-match-list.c b/src/ui/fma-match-list.c
index 58761d9..4d1c186 100644
--- a/src/ui/fma-match-list.c
+++ b/src/ui/fma-match-list.c
@@ -93,7 +93,7 @@ static ColumnHeaderStruct st_match_headers[] = {
 
 static void         create_tree_model( MatchListData *data );
 static void         initialize_window( MatchListData *data );
-static void         on_tree_selection_changed( NactTreeView *treeview, GList *selected_items, MatchListData 
*data );
+static void         on_tree_selection_changed( FMATreeView *treeview, GList *selected_items, MatchListData 
*data );
 
 static void         on_add_filter_clicked( GtkButton *button, MatchListData *data );
 static void         on_filter_clicked( GtkTreeViewColumn *treeviewcolumn, MatchListData *data );
@@ -258,7 +258,7 @@ initialize_window( MatchListData *data )
        GtkTreeViewColumn *column;
        GList *renderers;
        GtkTreeModel *model;
-       NactTreeView *treeview;
+       FMATreeView *treeview;
 
        g_return_if_fail( data != NULL );
 
@@ -324,7 +324,7 @@ initialize_window( MatchListData *data )
  * - update the object with a summary of the listbox contents
  */
 static void
-on_tree_selection_changed( NactTreeView *treeview, GList *selected_items, MatchListData *data )
+on_tree_selection_changed( FMATreeView *treeview, GList *selected_items, MatchListData *data )
 {
        static const gchar *thisfn = "fma_match_list_on_tree_selection_changed";
        FMAIContext *context;
@@ -335,7 +335,7 @@ on_tree_selection_changed( NactTreeView *treeview, GList *selected_items, MatchL
        GtkTreeViewColumn *column;
        GtkTreePath *path;
 
-       g_return_if_fail( treeview && NACT_IS_TREE_VIEW( treeview ));
+       g_return_if_fail( treeview && FMA_IS_TREE_VIEW( treeview ));
        g_return_if_fail( data != NULL );
 
        g_object_get( G_OBJECT( data->window ),
diff --git a/src/ui/fma-menu-edit.c b/src/ui/fma-menu-edit.c
index cd7469a..b4e28bc 100644
--- a/src/ui/fma-menu-edit.c
+++ b/src/ui/fma-menu-edit.c
@@ -44,7 +44,7 @@
 #include "fma-menu.h"
 #include "fma-menu-edit.h"
 #include "fma-tree-ieditable.h"
-#include "nact-tree-view.h"
+#include "fma-tree-view.h"
 
 static GList  *prepare_for_paste( FMAMainWindow *window, sMenuData *sdata );
 static GList  *get_deletables( FMAUpdater *updater, GList *tree, GSList **not_deletable );
@@ -207,7 +207,7 @@ fma_menu_edit_cut( FMAMainWindow *main_window )
        FMAClipboard *clipboard;
        GList *to_delete;
        GSList *ndeletables;
-       NactTreeView *view;
+       FMATreeView *view;
 
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
@@ -289,7 +289,7 @@ fma_menu_edit_paste( FMAMainWindow *main_window )
        static const gchar *thisfn = "fma_menu_edit_paste";
        sMenuData *sdata;
        GList *items;
-       NactTreeView *view;
+       FMATreeView *view;
 
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
@@ -325,7 +325,7 @@ fma_menu_edit_paste_into( FMAMainWindow *main_window )
        static const gchar *thisfn = "fma_menu_edit_paste_into";
        sMenuData *sdata;
        GList *items;
-       NactTreeView *view;
+       FMATreeView *view;
 
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
@@ -397,7 +397,7 @@ fma_menu_edit_duplicate( FMAMainWindow *main_window )
        GList *dup;
        FMAObject *obj;
        gboolean relabel;
-       NactTreeView *view;
+       FMATreeView *view;
 
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
@@ -453,7 +453,7 @@ fma_menu_edit_delete( FMAMainWindow *main_window )
        GList *items;
        GList *to_delete;
        GSList *ndeletables;
-       NactTreeView *view;
+       FMATreeView *view;
 
        g_debug( "%s: main_window=%p", thisfn, ( void * ) main_window );
        g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
diff --git a/src/ui/fma-menu-file.c b/src/ui/fma-menu-file.c
index 5cb9d68..bc7f486 100644
--- a/src/ui/fma-menu-file.c
+++ b/src/ui/fma-menu-file.c
@@ -126,7 +126,7 @@ fma_menu_file_new_menu( FMAMainWindow *main_window )
 {
        sMenuData *sdata;
        FMAObjectMenu *menu;
-       NactTreeView *items_view;
+       FMATreeView *items_view;
        GList *items;
 
        sdata = fma_menu_get_data( main_window );
@@ -150,7 +150,7 @@ fma_menu_file_new_action( FMAMainWindow *main_window )
 {
        sMenuData *sdata;
        FMAObjectAction *action;
-       NactTreeView *items_view;
+       FMATreeView *items_view;
        GList *items;
 
        sdata = fma_menu_get_data( main_window );
@@ -174,7 +174,7 @@ fma_menu_file_new_profile( FMAMainWindow *main_window )
 {
        FMAObjectAction *action;
        FMAObjectProfile *profile;
-       NactTreeView *items_view;
+       FMATreeView *items_view;
        GList *items;
 
        g_object_get(
@@ -230,7 +230,7 @@ fma_menu_file_save_items( FMAMainWindow *window )
 {
        static const gchar *thisfn = "fma_menu_file_save_items";
        sMenuData *sdata;
-       NactTreeView *items_view;
+       FMATreeView *items_view;
        GList *items, *it;
        GList *new_pivot;
        FMAObjectItem *duplicate;
@@ -245,7 +245,7 @@ fma_menu_file_save_items( FMAMainWindow *window )
         * and reset the corresponding modification flag
         */
        items_view = fma_main_window_get_items_view( window );
-       items = nact_tree_view_get_items( items_view );
+       items = fma_tree_view_get_items( items_view );
        fma_object_dump_tree( items );
        messages = NULL;
 
@@ -283,7 +283,7 @@ fma_menu_file_save_items( FMAMainWindow *window )
 
        } else {
                fma_object_free_items( items );
-               items = nact_tree_view_get_items( items_view );
+               items = fma_tree_view_get_items( items_view );
        }
 
        /* recursively save the modified items
diff --git a/src/ui/fma-menu.c b/src/ui/fma-menu.c
index 93f62c7..68bac0d 100644
--- a/src/ui/fma-menu.c
+++ b/src/ui/fma-menu.c
@@ -46,7 +46,7 @@
 #include "fma-menu-tools.h"
 */
 #include "fma-preferences-editor.h"
-#include "nact-tree-view.h"
+#include "fma-tree-view.h"
 
 static const gchar *st_uixml_actions    = PKGUIDIR "/fma-ui.actions";
 static const gchar *st_ui_app_menu      = "app-menu";
@@ -180,13 +180,13 @@ static sActionEntry st_menubar_entries[] = {
 };
 
 static void       free_menu_data( sMenuData *sdata );
-static void       on_open_context_menu( NactTreeView *treeview, GdkEventButton *event, FMAMainWindow *window 
);
+static void       on_open_context_menu( FMATreeView *treeview, GdkEventButton *event, FMAMainWindow *window 
);
 static void       on_popup_selection_done( GtkMenuShell *menushell, FMAMainWindow *window );
-static void       on_tree_view_count_changed( NactTreeView *treeview, gboolean reset, gint menus, gint 
actions, gint profiles, FMAMainWindow *window );
-static void       on_tree_view_focus_in( NactTreeView *treeview, FMAMainWindow *window );
-static void       on_tree_view_focus_out( NactTreeView *treeview, FMAMainWindow *window );
-static void       on_tree_view_modified_status_changed( NactTreeView *treeview, gboolean is_modified, 
FMAMainWindow *window );
-static void       on_tree_view_selection_changed( NactTreeView *treeview, GList *selected, FMAMainWindow 
*window );
+static void       on_tree_view_count_changed( FMATreeView *treeview, gboolean reset, gint menus, gint 
actions, gint profiles, FMAMainWindow *window );
+static void       on_tree_view_focus_in( FMATreeView *treeview, FMAMainWindow *window );
+static void       on_tree_view_focus_out( FMATreeView *treeview, FMAMainWindow *window );
+static void       on_tree_view_modified_status_changed( FMATreeView *treeview, gboolean is_modified, 
FMAMainWindow *window );
+static void       on_tree_view_selection_changed( FMATreeView *treeview, GList *selected, FMAMainWindow 
*window );
 static void       on_update_sensitivities( FMAMainWindow *window, void *empty );
 
 /**
@@ -308,7 +308,7 @@ fma_menu_win( FMAMainWindow *main_window )
        static const gchar *thisfn = "fma_menu_win";
        gint i;
        GtkApplication *application;
-       NactTreeView *treeview;
+       FMATreeView *treeview;
        sMenuData *sdata;
 
        sdata = fma_menu_get_data( main_window );
@@ -402,7 +402,7 @@ free_menu_data( sMenuData *sdata )
  * Opens a popup menu.
  */
 static void
-on_open_context_menu( NactTreeView *treeview, GdkEventButton *event, FMAMainWindow *window )
+on_open_context_menu( FMATreeView *treeview, GdkEventButton *event, FMAMainWindow *window )
 {
        sMenuData *sdata;
 
@@ -438,7 +438,7 @@ on_popup_selection_done( GtkMenuShell *menushell, FMAMainWindow *window )
  * that we are knowing if we have some exportables
  */
 static void
-on_tree_view_count_changed( NactTreeView *treeview, gboolean reset, gint menus, gint actions, gint profiles, 
FMAMainWindow *window )
+on_tree_view_count_changed( FMATreeView *treeview, gboolean reset, gint menus, gint actions, gint profiles, 
FMAMainWindow *window )
 {
        static const gchar *thisfn = "fma_menu_on_tree_view_count_changed";
        sMenuData *sdata;
@@ -477,7 +477,7 @@ on_tree_view_count_changed( NactTreeView *treeview, gboolean reset, gint menus,
 }
 
 static void
-on_tree_view_focus_in( NactTreeView *treeview, FMAMainWindow *window )
+on_tree_view_focus_in( FMATreeView *treeview, FMAMainWindow *window )
 {
        sMenuData *sdata;
 
@@ -488,7 +488,7 @@ on_tree_view_focus_in( NactTreeView *treeview, FMAMainWindow *window )
 }
 
 static void
-on_tree_view_focus_out( NactTreeView *treeview, FMAMainWindow *window )
+on_tree_view_focus_out( FMATreeView *treeview, FMAMainWindow *window )
 {
        sMenuData *sdata;
 
@@ -502,7 +502,7 @@ on_tree_view_focus_out( NactTreeView *treeview, FMAMainWindow *window )
  * the count of modified FMAObjectItem has changed
  */
 static void
-on_tree_view_modified_status_changed( NactTreeView *treeview, gboolean is_modified, FMAMainWindow *window )
+on_tree_view_modified_status_changed( FMATreeView *treeview, gboolean is_modified, FMAMainWindow *window )
 {
        static const gchar *thisfn = "fma_menu_on_tree_view_modified_status_changed";
        sMenuData *sdata;
@@ -529,7 +529,7 @@ on_tree_view_modified_status_changed( NactTreeView *treeview, gboolean is_modifi
  * of applying to valid candidates, and rejecting the others.
  */
 static void
-on_tree_view_selection_changed( NactTreeView *treeview, GList *selected, FMAMainWindow *window )
+on_tree_view_selection_changed( FMATreeView *treeview, GList *selected, FMAMainWindow *window )
 {
        static const gchar *thisfn = "fma_menu_on_tree_view_selection_changed";
        sMenuData *sdata;
@@ -677,12 +677,12 @@ on_win_brief_tree_store_dump( GSimpleAction *action, GVariant *parameter, gpoint
 static void
 on_win_collapse_all( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
-       NactTreeView *items_view;
+       FMATreeView *items_view;
 
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
 
        items_view = fma_main_window_get_items_view( FMA_MAIN_WINDOW( user_data ));
-       nact_tree_view_collapse_all( items_view );
+       fma_tree_view_collapse_all( items_view );
 }
 
 static void
@@ -728,12 +728,12 @@ on_win_duplicate( GSimpleAction *action, GVariant *parameter, gpointer user_data
 static void
 on_win_expand_all( GSimpleAction *action, GVariant *parameter, gpointer user_data )
 {
-       NactTreeView *items_view;
+       FMATreeView *items_view;
 
        g_return_if_fail( user_data && FMA_IS_MAIN_WINDOW( user_data ));
 
        items_view = fma_main_window_get_items_view( FMA_MAIN_WINDOW( user_data ));
-       nact_tree_view_expand_all( items_view );
+       fma_tree_view_expand_all( items_view );
 }
 
 static void
diff --git a/src/ui/fma-sort-buttons.c b/src/ui/fma-sort-buttons.c
index fb1fcf9..65b1e6a 100644
--- a/src/ui/fma-sort-buttons.c
+++ b/src/ui/fma-sort-buttons.c
@@ -38,7 +38,7 @@
 #include "fma-application.h"
 #include "fma-main-window.h"
 #include "fma-sort-buttons.h"
-#include "nact-tree-view.h"
+#include "fma-tree-view.h"
 
 struct _FMASortButtonsPrivate {
        gboolean        dispose_has_run;
@@ -72,7 +72,7 @@ static void  instance_finalize( GObject *application );
 static void  initialize_buttons( FMASortButtons *buttons, FMAMainWindow *window );
 static void  on_toggle_button_toggled( GtkToggleButton *button, FMASortButtons *buttons );
 static void  on_settings_order_mode_changed( const gchar *group, const gchar *key, gconstpointer new_value, 
gboolean mandatory, FMASortButtons *sort_buttons );
-static void  on_tree_view_count_changed( NactTreeView *treeview, gboolean reset, gint menus_count, gint 
actions_count, gint profiles_count, FMASortButtons *sort_buttons );
+static void  on_tree_view_count_changed( FMATreeView *treeview, gboolean reset, gint menus_count, gint 
actions_count, gint profiles_count, FMASortButtons *sort_buttons );
 static void  enable_buttons( const FMASortButtons *sort_buttons, gboolean enabled );
 static gint  toggle_group_get_from_mode( guint mode );
 static gint  toggle_group_get_from_button( GtkToggleButton *toggled_button );
@@ -230,7 +230,7 @@ fma_sort_buttons_new( FMAMainWindow *window )
 static void
 initialize_buttons( FMASortButtons *buttons, FMAMainWindow *window )
 {
-       NactTreeView *treeview;
+       FMATreeView *treeview;
        gint i;
 
        treeview = fma_main_window_get_items_view( window );
@@ -337,7 +337,7 @@ on_settings_order_mode_changed( const gchar *group, const gchar *key, gconstpoin
 }
 
 static void
-on_tree_view_count_changed( NactTreeView *treeview, gboolean reset, gint menus_count, gint actions_count, 
gint profiles_count, FMASortButtons *buttons )
+on_tree_view_count_changed( FMATreeView *treeview, gboolean reset, gint menus_count, gint actions_count, 
gint profiles_count, FMASortButtons *buttons )
 {
        static const gchar *thisfn = "fma_sort_buttons_on_tree_view_count_changed";
        FMASortButtonsPrivate *priv;
diff --git a/src/ui/fma-tree-ieditable.h b/src/ui/fma-tree-ieditable.h
index b8ffdb0..6c0e8dd 100644
--- a/src/ui/fma-tree-ieditable.h
+++ b/src/ui/fma-tree-ieditable.h
@@ -36,7 +36,7 @@
  * @short_description: The FMATreeIEditable interface definition
  * @include: ui/fma-tree-ieditable.h
  *
- * This interface is to be implemented by a NactTreeView which would
+ * This interface is to be implemented by a FMATreeView which would
  * want get edition features, such as inline edition, insert, delete,
  * and so on.
  *
diff --git a/src/ui/fma-tree-model-dnd.c b/src/ui/fma-tree-model-dnd.c
index 8ce985b..93a11b3 100644
--- a/src/ui/fma-tree-model-dnd.c
+++ b/src/ui/fma-tree-model-dnd.c
@@ -577,7 +577,7 @@ drop_inside( FMATreeModel *model, GtkTreePath *dest, GtkSelectionData  *selectio
        GtkTreeIter iter;
        GList *deletable;
        gboolean relabel;
-       NactTreeView *items_view;
+       FMATreeView *items_view;
 
        application = FMA_APPLICATION( gtk_window_get_application( GTK_WINDOW( model->private->window )));
        updater = fma_application_get_updater( application );
@@ -873,7 +873,7 @@ drop_uri_list( FMATreeModel *model, GtkTreePath *dest, GtkSelectionData  *select
        GSList *im;
        GList *imported, *overriden;
        const gchar *selection_data_data;
-       NactTreeView *view;
+       FMATreeView *view;
        GSList *messages;
        gchar *dlg_message;
        GtkWidget *dialog;
@@ -993,11 +993,11 @@ drop_uri_list( FMATreeModel *model, GtkTreePath *dest, GtkSelectionData  *select
 static FMAObjectItem *
 is_dropped_already_exists( const FMAObjectItem *importing, const FMAMainWindow *window )
 {
-       NactTreeView *items_view;
+       FMATreeView *items_view;
 
        gchar *id = fma_object_get_id( importing );
        items_view = fma_main_window_get_items_view( window );
-       FMAObjectItem *exists = nact_tree_view_get_item_by_id( items_view, id );
+       FMAObjectItem *exists = fma_tree_view_get_item_by_id( items_view, id );
        g_free( id );
 
        return( exists );
diff --git a/src/ui/nact-tree-view.c b/src/ui/fma-tree-view.c
similarity index 78%
rename from src/ui/nact-tree-view.c
rename to src/ui/fma-tree-view.c
index d6ffc49..ca2b52e 100644
--- a/src/ui/nact-tree-view.c
+++ b/src/ui/fma-tree-view.c
@@ -40,18 +40,18 @@
 #include "base-keysyms.h"
 #include "fma-application.h"
 #include "fma-main-window.h"
-#include "nact-tree-view.h"
+#include "fma-tree-view.h"
 #include "fma-tree-model.h"
 #include "fma-tree-ieditable.h"
 
 /* private instance data
  */
-struct _NactTreeViewPrivate {
+struct _FMATreeViewPrivate {
        gboolean        dispose_has_run;
 
        /* properties set at instanciation time
         */
-       FMAMainWindow *window;
+       FMAMainWindow  *window;
 
        /* initialization
         */
@@ -89,41 +89,41 @@ enum {
 
 /* iter on selection prototype
  */
-typedef gboolean ( *FnIterOnSelection )( NactTreeView *, GtkTreeModel *, GtkTreeIter *, FMAObject *, 
gpointer );
+typedef gboolean ( *FnIterOnSelection )( FMATreeView *, GtkTreeModel *, GtkTreeIter *, FMAObject *, gpointer 
);
 
 static gint          st_signals[ LAST_SIGNAL ] = { 0 };
 static GObjectClass *st_parent_class           = NULL;
 
 static GType      register_type( void );
-static void       class_init( NactTreeViewClass *klass );
+static void       class_init( FMATreeViewClass *klass );
 static void       tree_ieditable_iface_init( FMATreeIEditableInterface *iface, void *user_data );
 static void       instance_init( GTypeInstance *instance, gpointer klass );
 static void       instance_dispose( GObject *application );
 static void       instance_finalize( GObject *application );
-static void       initialize_gtk( NactTreeView *view );
-static gboolean   on_button_press_event( GtkWidget *widget, GdkEventButton *event, NactTreeView *view );
-static gboolean   on_focus_in( GtkWidget *widget, GdkEventFocus *event, NactTreeView *view );
-static gboolean   on_focus_out( GtkWidget *widget, GdkEventFocus *event, NactTreeView *view );
-static gboolean   on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, NactTreeView *view );
-static gboolean   on_popup_menu( GtkWidget *widget, NactTreeView *view );
-static void       on_selection_changed( GtkTreeSelection *selection, NactTreeView *view );
-static void       on_tree_view_realized( NactTreeView *treeview, void *empty );
-static void       clear_selection( NactTreeView *view );
-static void       on_selection_changed_cleanup_handler( NactTreeView *tview, GList *selected_items );
-static void       display_label( GtkTreeViewColumn *column, GtkCellRenderer *cell, GtkTreeModel *model, 
GtkTreeIter *iter, NactTreeView *view );
-static void       extend_selection_to_children( NactTreeView *view, GtkTreeModel *model, GtkTreeIter *parent 
);
-static GList     *get_selected_items( NactTreeView *view );
-static void       iter_on_selection( NactTreeView *view, FnIterOnSelection fn_iter, gpointer user_data );
-static void       navigate_to_child( NactTreeView *view );
-static void       navigate_to_parent( NactTreeView *view );
-static void       do_open_popup( NactTreeView *view, GdkEventButton *event );
-static void       select_row_at_path_by_string( NactTreeView *view, const gchar *path );
-static void       toggle_collapse( NactTreeView *view );
-static gboolean   toggle_collapse_iter( NactTreeView *view, GtkTreeModel *model, GtkTreeIter *iter, 
FMAObject *object, gpointer user_data );
+static void       initialize_gtk( FMATreeView *view );
+static gboolean   on_button_press_event( GtkWidget *widget, GdkEventButton *event, FMATreeView *view );
+static gboolean   on_focus_in( GtkWidget *widget, GdkEventFocus *event, FMATreeView *view );
+static gboolean   on_focus_out( GtkWidget *widget, GdkEventFocus *event, FMATreeView *view );
+static gboolean   on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, FMATreeView *view );
+static gboolean   on_popup_menu( GtkWidget *widget, FMATreeView *view );
+static void       on_selection_changed( GtkTreeSelection *selection, FMATreeView *view );
+static void       on_tree_view_realized( FMATreeView *treeview, void *empty );
+static void       clear_selection( FMATreeView *view );
+static void       on_selection_changed_cleanup_handler( FMATreeView *tview, GList *selected_items );
+static void       display_label( GtkTreeViewColumn *column, GtkCellRenderer *cell, GtkTreeModel *model, 
GtkTreeIter *iter, FMATreeView *view );
+static void       extend_selection_to_children( FMATreeView *view, GtkTreeModel *model, GtkTreeIter *parent 
);
+static GList     *get_selected_items( FMATreeView *view );
+static void       iter_on_selection( FMATreeView *view, FnIterOnSelection fn_iter, gpointer user_data );
+static void       navigate_to_child( FMATreeView *view );
+static void       navigate_to_parent( FMATreeView *view );
+static void       do_open_popup( FMATreeView *view, GdkEventButton *event );
+static void       select_row_at_path_by_string( FMATreeView *view, const gchar *path );
+static void       toggle_collapse( FMATreeView *view );
+static gboolean   toggle_collapse_iter( FMATreeView *view, GtkTreeModel *model, GtkTreeIter *iter, FMAObject 
*object, gpointer user_data );
 static void       toggle_collapse_row( GtkTreeView *treeview, GtkTreePath *path, guint *toggle );
 
 GType
-nact_tree_view_get_type( void )
+fma_tree_view_get_type( void )
 {
        static GType type = 0;
 
@@ -144,32 +144,32 @@ nact_tree_view_get_type( void )
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "nact_tree_view_register_type";
+       static const gchar *thisfn = "fma_tree_view_register_type";
        GType type;
 
        static GTypeInfo info = {
-               sizeof( NactTreeViewClass ),
+               sizeof( FMATreeViewClass ),
                ( GBaseInitFunc ) NULL,
                ( GBaseFinalizeFunc ) NULL,
                ( GClassInitFunc ) class_init,
                NULL,
                NULL,
-               sizeof( NactTreeView ),
+               sizeof( FMATreeView ),
                0,
                ( GInstanceInitFunc ) instance_init
        };
 
        g_debug( "%s", thisfn );
 
-       type = g_type_register_static( GTK_TYPE_BIN, "NactTreeView", &info, 0 );
+       type = g_type_register_static( GTK_TYPE_BIN, "FMATreeView", &info, 0 );
 
        return( type );
 }
 
 static void
-class_init( NactTreeViewClass *klass )
+class_init( FMATreeViewClass *klass )
 {
-       static const gchar *thisfn = "nact_tree_view_class_init";
+       static const gchar *thisfn = "fma_tree_view_class_init";
        GObjectClass *object_class;
 
        g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
@@ -181,7 +181,7 @@ class_init( NactTreeViewClass *klass )
        object_class->finalize = instance_finalize;
 
        /**
-        * NactTreeView::tree-signal-count-changed:
+        * FMATreeView::tree-signal-count-changed:
         *
         * This signal is emitted on BaseWindow parent when the count of items
         * has changed in the underlying tree store.
@@ -208,7 +208,7 @@ class_init( NactTreeViewClass *klass )
         */
        st_signals[ COUNT_CHANGED ] = g_signal_new(
                        TREE_SIGNAL_COUNT_CHANGED,
-                       NACT_TYPE_TREE_VIEW,
+                       FMA_TYPE_TREE_VIEW,
                        G_SIGNAL_RUN_LAST,
                        0,                                              /* no default handler */
                        NULL,
@@ -219,7 +219,7 @@ class_init( NactTreeViewClass *klass )
                        G_TYPE_BOOLEAN, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT );
 
        /**
-        * NactTreeView::tree-signal-focus-in:
+        * FMATreeView::tree-signal-focus-in:
         *
         * This signal is emitted on the window when the view gains the focus.
         * In particular, edition menu is disabled outside of the treeview.
@@ -231,7 +231,7 @@ class_init( NactTreeViewClass *klass )
         */
        st_signals[ FOCUS_IN ] = g_signal_new(
                        TREE_SIGNAL_FOCUS_IN,
-                       NACT_TYPE_TREE_VIEW,
+                       FMA_TYPE_TREE_VIEW,
                        G_SIGNAL_RUN_LAST,
                        0,
                        NULL,
@@ -241,7 +241,7 @@ class_init( NactTreeViewClass *klass )
                        0 );
 
        /**
-        * NactTreeView::tree-signal-focus-out:
+        * FMATreeView::tree-signal-focus-out:
         *
         * This signal is emitted on the window when the view loses the focus.
         * In particular, edition menu is disabled outside of the treeview.
@@ -253,7 +253,7 @@ class_init( NactTreeViewClass *klass )
         */
        st_signals[ FOCUS_OUT ] = g_signal_new(
                        TREE_SIGNAL_FOCUS_OUT,
-                       NACT_TYPE_TREE_VIEW,
+                       FMA_TYPE_TREE_VIEW,
                        G_SIGNAL_RUN_LAST,
                        0,
                        NULL,
@@ -263,7 +263,7 @@ class_init( NactTreeViewClass *klass )
                        0 );
 
        /**
-        * NactTreeView::tree-signal-level-zero-changed:
+        * FMATreeView::tree-signal-level-zero-changed:
         *
         * This signal is emitted on the BaseWindow each time the level zero
         * has changed because an item has been removed or inserted, or when
@@ -278,7 +278,7 @@ class_init( NactTreeViewClass *klass )
         */
        st_signals[ LEVEL_ZERO_CHANGED ] = g_signal_new(
                        TREE_SIGNAL_LEVEL_ZERO_CHANGED,
-                       NACT_TYPE_TREE_VIEW,
+                       FMA_TYPE_TREE_VIEW,
                        G_SIGNAL_RUN_LAST,
                        0,                                      /* no default handler */
                        NULL,
@@ -289,7 +289,7 @@ class_init( NactTreeViewClass *klass )
                        G_TYPE_BOOLEAN );
 
        /**
-        * NactTreeView::tree-signal-modified-status-changed:
+        * FMATreeView::tree-signal-modified-status-changed:
         *
         * This signal is emitted on the BaseWindow when the view detects that
         * the count of modified FMAObjectItems has changed, when an item is
@@ -306,7 +306,7 @@ class_init( NactTreeViewClass *klass )
         */
        st_signals[ MODIFIED_STATUS ] = g_signal_new(
                        TREE_SIGNAL_MODIFIED_STATUS_CHANGED,
-                       NACT_TYPE_TREE_VIEW,
+                       FMA_TYPE_TREE_VIEW,
                        G_SIGNAL_RUN_LAST,
                        0,
                        NULL,
@@ -317,7 +317,7 @@ class_init( NactTreeViewClass *klass )
                        G_TYPE_BOOLEAN );
 
        /**
-        * NactTreeView::tree-selection-changed:
+        * FMATreeView::tree-selection-changed:
         *
         * This signal is emitted on the treeview each time the selection
         * has changed after having set the current item/profile/context
@@ -331,13 +331,13 @@ class_init( NactTreeViewClass *klass )
         * - a #GList of currently selected #FMAObjectItems.
         *
         * Handler prototype:
-        *   void handler( NactTreeView *tview,
+        *   void handler( FMATreeView *tview,
         *                              GList       *selected,
         *                              void        *user_data );
         */
        st_signals[ SELECTION_CHANGED ] = g_signal_new_class_handler(
                        TREE_SIGNAL_SELECTION_CHANGED,
-                       NACT_TYPE_TREE_VIEW,
+                       FMA_TYPE_TREE_VIEW,
                        G_SIGNAL_RUN_CLEANUP,
                        G_CALLBACK( on_selection_changed_cleanup_handler ),
                        NULL,
@@ -348,7 +348,7 @@ class_init( NactTreeViewClass *klass )
                        G_TYPE_POINTER );
 
        /**
-        * NactTreeView::tree-signal-open-popup
+        * FMATreeView::tree-signal-open-popup
         *
         * This signal is emitted on the treeview when the user right
         * clicks somewhere (on an active zone).
@@ -357,13 +357,13 @@ class_init( NactTreeViewClass *klass )
         * - the GdkEvent
         *
         * Handler prototype:
-        *   void handler( NactTreeView *tview,
+        *   void handler( FMATreeView *tview,
         *                              GdkEvent    *event,
         *                              void        *user_data );
         */
        st_signals[ OPEN_POPUP ] = g_signal_new(
                        TREE_SIGNAL_CONTEXT_MENU,
-                       NACT_TYPE_TREE_VIEW,
+                       FMA_TYPE_TREE_VIEW,
                        G_SIGNAL_RUN_LAST,
                        0,
                        NULL,
@@ -385,17 +385,17 @@ tree_ieditable_iface_init( FMATreeIEditableInterface *iface, void *user_data )
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-       static const gchar *thisfn = "nact_tree_view_instance_init";
-       NactTreeView *self;
+       static const gchar *thisfn = "fma_tree_view_instance_init";
+       FMATreeView *self;
 
-       g_return_if_fail( NACT_IS_TREE_VIEW( instance ));
+       g_return_if_fail( FMA_IS_TREE_VIEW( instance ));
 
        g_debug( "%s: instance=%p (%s), klass=%p",
                        thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
 
-       self = NACT_TREE_VIEW( instance );
+       self = FMA_TREE_VIEW( instance );
 
-       self->private = g_new0( NactTreeViewPrivate, 1 );
+       self->private = g_new0( FMATreeViewPrivate, 1 );
 
        self->private->dispose_has_run = FALSE;
 }
@@ -403,12 +403,12 @@ instance_init( GTypeInstance *instance, gpointer klass )
 static void
 instance_dispose( GObject *object )
 {
-       static const gchar *thisfn = "nact_tree_view_instance_dispose";
-       NactTreeView *self;
+       static const gchar *thisfn = "fma_tree_view_instance_dispose";
+       FMATreeView *self;
 
-       g_return_if_fail( NACT_IS_TREE_VIEW( object ));
+       g_return_if_fail( FMA_IS_TREE_VIEW( object ));
 
-       self = NACT_TREE_VIEW( object );
+       self = FMA_TREE_VIEW( object );
 
        if( !self->private->dispose_has_run ){
                g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
@@ -429,14 +429,14 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *instance )
 {
-       static const gchar *thisfn = "nact_tree_view_instance_finalize";
-       NactTreeView *self;
+       static const gchar *thisfn = "fma_tree_view_instance_finalize";
+       FMATreeView *self;
 
-       g_return_if_fail( NACT_IS_TREE_VIEW( instance ));
+       g_return_if_fail( FMA_IS_TREE_VIEW( instance ));
 
        g_debug( "%s: instance=%p (%s)", thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ));
 
-       self = NACT_TREE_VIEW( instance );
+       self = FMA_TREE_VIEW( instance );
 
        g_free( self->private );
 
@@ -447,18 +447,18 @@ instance_finalize( GObject *instance )
 }
 
 /**
- * nact_tree_view_new:
+ * fma_tree_view_new:
  *
- * Returns: a newly allocated NactTreeView object, which will be owned
+ * Returns: a newly allocated FMATreeView object, which will be owned
  * by the caller. It is useless to unref it as it will be automatically
  * destroyed at @window finalization.
  */
-NactTreeView *
-nact_tree_view_new( FMAMainWindow *main_window )
+FMATreeView *
+fma_tree_view_new( FMAMainWindow *main_window )
 {
-       NactTreeView *view;
+       FMATreeView *view;
 
-       view = g_object_new( NACT_TYPE_TREE_VIEW, NULL );
+       view = g_object_new( FMA_TYPE_TREE_VIEW, NULL );
        view->private->window = main_window;
 
        initialize_gtk( view );
@@ -470,10 +470,10 @@ nact_tree_view_new( FMAMainWindow *main_window )
 }
 
 static void
-initialize_gtk( NactTreeView *view )
+initialize_gtk( FMATreeView *view )
 {
-       static const gchar *thisfn = "nact_tree_view_initialize_gtk";
-       NactTreeViewPrivate *priv;
+       static const gchar *thisfn = "fma_tree_view_initialize_gtk";
+       FMATreeViewPrivate *priv;
        GtkWidget *scrolled, *tview;
        FMATreeModel *model;
        GtkTreeViewColumn *column;
@@ -530,20 +530,20 @@ initialize_gtk( NactTreeView *view )
 }
 
 /**
- * nact_tree_view_set_mnemonic:
- * @view: this #NactTreeView
+ * fma_tree_view_set_mnemonic:
+ * @view: this #FMATreeView
  * @parent: a parent container of the mnemonic label
  * @widget_name: the name of the mnemonic label
  *
  * Setup the mnemonic label
  */
 void
-nact_tree_view_set_mnemonic( NactTreeView *view, GtkContainer *parent, const gchar *widget_name )
+fma_tree_view_set_mnemonic( FMATreeView *view, GtkContainer *parent, const gchar *widget_name )
 {
-       NactTreeViewPrivate *priv;
+       FMATreeViewPrivate *priv;
        GtkWidget *label;
 
-       g_return_if_fail( view && NACT_IS_TREE_VIEW( view ));
+       g_return_if_fail( view && FMA_IS_TREE_VIEW( view ));
        g_return_if_fail( widget_name && g_utf8_strlen( widget_name, -1 ));
 
        priv = view->private;
@@ -557,22 +557,22 @@ nact_tree_view_set_mnemonic( NactTreeView *view, GtkContainer *parent, const gch
 }
 
 /**
- * nact_tree_view_set_edition_mode:
- * @view: this #NactTreeView
+ * fma_tree_view_set_edition_mode:
+ * @view: this #FMATreeView
  * @mode: the edition mode
  *
  * Setup the edition mode
  */
 void
-nact_tree_view_set_edition_mode( NactTreeView *view, guint mode )
+fma_tree_view_set_edition_mode( FMATreeView *view, guint mode )
 {
-       NactTreeViewPrivate *priv;
+       FMATreeViewPrivate *priv;
        GtkTreeViewColumn *column;
        GList *renderers;
        GtkCellRenderer *renderer;
        GtkTreeModel *tmodel;
 
-       g_return_if_fail( view && NACT_IS_TREE_VIEW( view ));
+       g_return_if_fail( view && FMA_IS_TREE_VIEW( view ));
 
        priv = view->private;
 
@@ -599,7 +599,7 @@ nact_tree_view_set_edition_mode( NactTreeView *view, guint mode )
 }
 
 static gboolean
-on_button_press_event( GtkWidget *widget, GdkEventButton *event, NactTreeView *view )
+on_button_press_event( GtkWidget *widget, GdkEventButton *event, FMATreeView *view )
 {
        gboolean stop = FALSE;
 
@@ -619,7 +619,7 @@ on_button_press_event( GtkWidget *widget, GdkEventButton *event, NactTreeView *v
  * delete current row in the list!
  */
 static gboolean
-on_focus_in( GtkWidget *widget, GdkEventFocus *event, NactTreeView *view )
+on_focus_in( GtkWidget *widget, GdkEventFocus *event, FMATreeView *view )
 {
        gboolean stop = FALSE;
 
@@ -629,7 +629,7 @@ on_focus_in( GtkWidget *widget, GdkEventFocus *event, NactTreeView *view )
 }
 
 static gboolean
-on_focus_out( GtkWidget *widget, GdkEventFocus *event, NactTreeView *view )
+on_focus_out( GtkWidget *widget, GdkEventFocus *event, FMATreeView *view )
 {
        gboolean stop = FALSE;
 
@@ -639,7 +639,7 @@ on_focus_out( GtkWidget *widget, GdkEventFocus *event, NactTreeView *view )
 }
 
 static gboolean
-on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, NactTreeView *view )
+on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, FMATreeView *view )
 {
        gboolean stop = FALSE;
 
@@ -663,7 +663,7 @@ on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, NactTreeView *view
  * triggered by the "popup-menu" signal, itself triggered by the keybindings
  */
 static gboolean
-on_popup_menu( GtkWidget *widget, NactTreeView *view )
+on_popup_menu( GtkWidget *widget, FMATreeView *view )
 {
        do_open_popup( view, NULL );
        return( TRUE );
@@ -672,9 +672,9 @@ on_popup_menu( GtkWidget *widget, NactTreeView *view )
  * handles the "changed" signal emitted on the GtkTreeSelection
  */
 static void
-on_selection_changed( GtkTreeSelection *selection, NactTreeView *view )
+on_selection_changed( GtkTreeSelection *selection, FMATreeView *view )
 {
-       static const gchar *thisfn = "nact_tree_view_on_selection_changed";
+       static const gchar *thisfn = "fma_tree_view_on_selection_changed";
        GList *selected_items;
 
        if( view->private->notify_allowed ){
@@ -685,14 +685,14 @@ on_selection_changed( GtkTreeSelection *selection, NactTreeView *view )
 }
 
 /*
- * the NactTreeView is realized
+ * the FMATreeView is realized
  */
 static void
-on_tree_view_realized( NactTreeView *treeview, void *empty )
+on_tree_view_realized( FMATreeView *treeview, void *empty )
 {
-       NactTreeViewPrivate *priv;
+       FMATreeViewPrivate *priv;
 
-       g_debug( "nact_tree_view_on_tree_view_realized" );
+       g_debug( "fma_tree_view_on_tree_view_realized" );
 
        priv = treeview->private;
 
@@ -721,8 +721,8 @@ on_tree_view_realized( NactTreeView *treeview, void *empty )
 }
 
 /**
- * nact_tree_view_fill:
- * @view: this #NactTreeView instance.
+ * fma_tree_view_fill:
+ * @view: this #FMATreeView instance.
  *
  * Fill the tree view with the provided list of items.
  *
@@ -731,13 +731,13 @@ on_tree_view_realized( NactTreeView *treeview, void *empty )
  * selection-changed messages.
  */
 void
-nact_tree_view_fill( NactTreeView *view, GList *items )
+fma_tree_view_fill( FMATreeView *view, GList *items )
 {
-       static const gchar *thisfn = "nact_tree_view_fill";
+       static const gchar *thisfn = "fma_tree_view_fill";
        FMATreeModel *model;
        gint nb_menus, nb_actions, nb_profiles;
 
-       g_return_if_fail( NACT_IS_TREE_VIEW( view ));
+       g_return_if_fail( FMA_IS_TREE_VIEW( view ));
 
        if( !view->private->dispose_has_run ){
                g_debug( "%s: view=%p, items=%p (count=%u)",
@@ -759,17 +759,17 @@ nact_tree_view_fill( NactTreeView *view, GList *items )
 }
 
 /**
- * nact_tree_view_are_notify_allowed:
- * @view: this #NactTreeView instance.
+ * fma_tree_view_are_notify_allowed:
+ * @view: this #FMATreeView instance.
  *
  * Returns: %TRUE if notifications are allowed, %FALSE else.
  */
 gboolean
-nact_tree_view_are_notify_allowed( const NactTreeView *view )
+fma_tree_view_are_notify_allowed( const FMATreeView *view )
 {
        gboolean are_allowed;
 
-       g_return_val_if_fail( NACT_IS_TREE_VIEW( view ), FALSE );
+       g_return_val_if_fail( FMA_IS_TREE_VIEW( view ), FALSE );
 
        are_allowed = FALSE;
 
@@ -782,14 +782,14 @@ nact_tree_view_are_notify_allowed( const NactTreeView *view )
 }
 
 /**
- * nact_tree_view_set_notify_allowed:
- * @view: this #NactTreeView instance.
+ * fma_tree_view_set_notify_allowed:
+ * @view: this #FMATreeView instance.
  * @allow: whether the notifications are to be allowed.
  */
 void
-nact_tree_view_set_notify_allowed( NactTreeView *view, gboolean allow )
+fma_tree_view_set_notify_allowed( FMATreeView *view, gboolean allow )
 {
-       g_return_if_fail( NACT_IS_TREE_VIEW( view ));
+       g_return_if_fail( FMA_IS_TREE_VIEW( view ));
 
        if( !view->private->dispose_has_run ){
 
@@ -798,15 +798,15 @@ nact_tree_view_set_notify_allowed( NactTreeView *view, gboolean allow )
 }
 
 /**
- * nact_tree_view_collapse_all:
- * @view: this #NactTreeView instance.
+ * fma_tree_view_collapse_all:
+ * @view: this #FMATreeView instance.
  *
  * Collapse all the tree hierarchy.
  */
 void
-nact_tree_view_collapse_all( const NactTreeView *view )
+fma_tree_view_collapse_all( const FMATreeView *view )
 {
-       g_return_if_fail( NACT_IS_TREE_VIEW( view ));
+       g_return_if_fail( FMA_IS_TREE_VIEW( view ));
 
        if( !view->private->dispose_has_run ){
 
@@ -815,15 +815,15 @@ nact_tree_view_collapse_all( const NactTreeView *view )
 }
 
 /**
- * nact_tree_view_expand_all:
- * @view: this #NactTreeView instance.
+ * fma_tree_view_expand_all:
+ * @view: this #FMATreeView instance.
  *
  * Collapse all the tree hierarchy.
  */
 void
-nact_tree_view_expand_all( const NactTreeView *view )
+fma_tree_view_expand_all( const FMATreeView *view )
 {
-       g_return_if_fail( NACT_IS_TREE_VIEW( view ));
+       g_return_if_fail( FMA_IS_TREE_VIEW( view ));
 
        if( !view->private->dispose_has_run ){
 
@@ -832,8 +832,8 @@ nact_tree_view_expand_all( const NactTreeView *view )
 }
 
 /**
- * nact_tree_view_get_item_by_id:
- * @view: this #NactTreeView instance.
+ * fma_tree_view_get_item_by_id:
+ * @view: this #FMATreeView instance.
  * @id: the searched #FMAObjectItem.
  *
  * Returns: a pointer on the searched #FMAObjectItem if it exists, or %NULL.
@@ -842,12 +842,12 @@ nact_tree_view_expand_all( const NactTreeView *view )
  * not be released by the caller.
  */
 FMAObjectItem *
-nact_tree_view_get_item_by_id( const NactTreeView *view, const gchar *id )
+fma_tree_view_get_item_by_id( const FMATreeView *view, const gchar *id )
 {
        FMAObjectItem *item;
        FMATreeModel *model;
 
-       g_return_val_if_fail( NACT_IS_TREE_VIEW( view ), NULL );
+       g_return_val_if_fail( FMA_IS_TREE_VIEW( view ), NULL );
 
        item = NULL;
 
@@ -861,34 +861,34 @@ nact_tree_view_get_item_by_id( const NactTreeView *view, const gchar *id )
 }
 
 /**
- * nact_tree_view_get_items:
- * @view: this #NactTreeView instance.
+ * fma_tree_view_get_items:
+ * @view: this #FMATreeView instance.
  *
  * Returns: the content of the current tree as a newly allocated list
  * which should be fma_object_free_items() by the caller.
  */
 GList *
-nact_tree_view_get_items( const NactTreeView *view )
+fma_tree_view_get_items( const FMATreeView *view )
 {
-       return( nact_tree_view_get_items_ex( view, TREE_LIST_ALL ));
+       return( fma_tree_view_get_items_ex( view, TREE_LIST_ALL ));
 }
 
 /**
- * nact_tree_view_get_items_ex:
- * @view: this #NactTreeView instance.
+ * fma_tree_view_get_items_ex:
+ * @view: this #FMATreeView instance.
  * @mode: the list content
  *
  * Returns: the content of the current tree as a newly allocated list
  * which should be fma_object_free_items() by the caller.
  */
 GList *
-nact_tree_view_get_items_ex( const NactTreeView *view, guint mode )
+fma_tree_view_get_items_ex( const FMATreeView *view, guint mode )
 {
        GList *items;
        FMATreeModel *model;
        GList *deleted;
 
-       g_return_val_if_fail( NACT_IS_TREE_VIEW( view ), NULL );
+       g_return_val_if_fail( FMA_IS_TREE_VIEW( view ), NULL );
 
        items = NULL;
 
@@ -912,8 +912,8 @@ nact_tree_view_get_items_ex( const NactTreeView *view, guint mode )
 }
 
 /**
- * nact_tree_view_select_row_at_path:
- * @view: this #NactTreeView object.
+ * fma_tree_view_select_row_at_path:
+ * @view: this #FMATreeView object.
  * @path: the #GtkTreePath to be selected.
  *
  * Select the row at the required path, or the immediate previous, or
@@ -923,15 +923,15 @@ nact_tree_view_get_items_ex( const NactTreeView *view, guint mode )
  * message with an empty selection.
  */
 void
-nact_tree_view_select_row_at_path( NactTreeView *view, GtkTreePath *path )
+fma_tree_view_select_row_at_path( FMATreeView *view, GtkTreePath *path )
 {
-       static const gchar *thisfn = "nact_tree_view_select_row_at_path";
+       static const gchar *thisfn = "fma_tree_view_select_row_at_path";
        gchar *path_str;
        GtkTreeIter iter;
        GtkTreeModel *model;
        gboolean something = FALSE;
 
-       g_return_if_fail( NACT_IS_TREE_VIEW( view ));
+       g_return_if_fail( FMA_IS_TREE_VIEW( view ));
 
        if( !view->private->dispose_has_run ){
 
@@ -976,7 +976,7 @@ nact_tree_view_select_row_at_path( NactTreeView *view, GtkTreePath *path )
 }
 
 static void
-clear_selection( NactTreeView *view )
+clear_selection( FMATreeView *view )
 {
        GtkTreeSelection *selection;
 
@@ -988,9 +988,9 @@ clear_selection( NactTreeView *view )
  * signal cleanup handler
  */
 static void
-on_selection_changed_cleanup_handler( NactTreeView *tview, GList *selected_items )
+on_selection_changed_cleanup_handler( FMATreeView *tview, GList *selected_items )
 {
-       static const gchar *thisfn = "nact_tree_view_on_selection_changed_cleanup_handler";
+       static const gchar *thisfn = "fma_tree_view_on_selection_changed_cleanup_handler";
 
        g_debug( "%s: tview=%p, selected_items=%p (count=%u)",
                        thisfn, ( void * ) tview,
@@ -1004,7 +1004,7 @@ on_selection_changed_cleanup_handler( NactTreeView *tview, GList *selected_items
  * item not saveable (invalid): red
  */
 static void
-display_label( GtkTreeViewColumn *column, GtkCellRenderer *cell, GtkTreeModel *model, GtkTreeIter *iter, 
NactTreeView *view )
+display_label( GtkTreeViewColumn *column, GtkCellRenderer *cell, GtkTreeModel *model, GtkTreeIter *iter, 
FMATreeView *view )
 {
        FMAObject *object;
        gchar *label;
@@ -1038,7 +1038,7 @@ display_label( GtkTreeViewColumn *column, GtkCellRenderer *cell, GtkTreeModel *m
  * when expanding a selected row which has children
  */
 static void
-extend_selection_to_children( NactTreeView *view, GtkTreeModel *model, GtkTreeIter *parent )
+extend_selection_to_children( FMATreeView *view, GtkTreeModel *model, GtkTreeIter *parent )
 {
        GtkTreeSelection *selection;
        GtkTreeIter iter;
@@ -1057,7 +1057,7 @@ extend_selection_to_children( NactTreeView *view, GtkTreeModel *model, GtkTreeIt
 
 /*
  * get_selected_items:
- * @view: this #NactTreeView instance.
+ * @view: this #FMATreeView instance.
  *
  * We acquire here a new reference on objects corresponding to actually
  * selected rows, and their children.
@@ -1066,9 +1066,9 @@ extend_selection_to_children( NactTreeView *view, GtkTreeModel *model, GtkTreeIt
  * which should be fma_object_free_items() by the caller.
  */
 static GList *
-get_selected_items( NactTreeView *view )
+get_selected_items( FMATreeView *view )
 {
-       static const gchar *thisfn = "nact_tree_view_get_selected_items";
+       static const gchar *thisfn = "fma_tree_view_get_selected_items";
        GList *items;
        GtkTreeSelection *selection;
        GtkTreeModel *model;
@@ -1099,7 +1099,7 @@ get_selected_items( NactTreeView *view )
 }
 
 static void
-iter_on_selection( NactTreeView *view, FnIterOnSelection fn_iter, gpointer user_data )
+iter_on_selection( FMATreeView *view, FnIterOnSelection fn_iter, gpointer user_data )
 {
        GtkTreeSelection *selection;
        GtkTreeModel *model;
@@ -1130,7 +1130,7 @@ iter_on_selection( NactTreeView *view, FnIterOnSelection fn_iter, gpointer user_
 
 /*
  * navigate_to_child:
- * @view: this #NactTreeView object.
+ * @view: this #FMATreeView object.
  *
  * On right arrow, if collapsed, then expand
  * if already expanded, then goto first child
@@ -1140,7 +1140,7 @@ iter_on_selection( NactTreeView *view, FnIterOnSelection fn_iter, gpointer user_
  * trying to expand it has no visible effect.
  */
 static void
-navigate_to_child( NactTreeView *view )
+navigate_to_child( FMATreeView *view )
 {
        GtkTreeSelection *selection;
        GList *listrows;
@@ -1164,7 +1164,7 @@ navigate_to_child( NactTreeView *view )
                        if( gtk_tree_model_iter_has_child( model, &iter )){
                                child_path = gtk_tree_path_copy( path );
                                gtk_tree_path_append_index( child_path, 0 );
-                               nact_tree_view_select_row_at_path( view, child_path );
+                               fma_tree_view_select_row_at_path( view, child_path );
                                gtk_tree_path_free( child_path );
                        }
                }
@@ -1176,7 +1176,7 @@ navigate_to_child( NactTreeView *view )
 
 /*
  * navigate_to_parent:
- * @view: this #NactTreeView object.
+ * @view: this #FMATreeView object.
  *
  * On left arrow, go to the parent.
  * if already on a parent, collapse it
@@ -1186,7 +1186,7 @@ navigate_to_child( NactTreeView *view )
  * this means that depth is always >= 1, with depth=1 being the root.
  */
 static void
-navigate_to_parent( NactTreeView *view )
+navigate_to_parent( FMATreeView *view )
 {
        GtkTreeSelection *selection;
        GtkTreeModel *model;
@@ -1206,7 +1206,7 @@ navigate_to_parent( NactTreeView *view )
                } else if( gtk_tree_path_get_depth( path ) > 1 ){
                        parent_path = gtk_tree_path_copy( path );
                        gtk_tree_path_up( parent_path );
-                       nact_tree_view_select_row_at_path( view, parent_path );
+                       fma_tree_view_select_row_at_path( view, parent_path );
                        gtk_tree_path_free( parent_path );
                }
        }
@@ -1216,16 +1216,16 @@ navigate_to_parent( NactTreeView *view )
 }
 
 static void
-do_open_popup( NactTreeView *view, GdkEventButton *event )
+do_open_popup( FMATreeView *view, GdkEventButton *event )
 {
-       NactTreeViewPrivate *priv;
+       FMATreeViewPrivate *priv;
        GtkTreePath *path;
 
        priv = view->private;
 
        if( event ){
                if( gtk_tree_view_get_path_at_pos( priv->tree_view, event->x, event->y, &path, NULL, NULL, 
NULL )){
-                       nact_tree_view_select_row_at_path( view, path );
+                       fma_tree_view_select_row_at_path( view, path );
                        gtk_tree_path_free( path );
                }
        }
@@ -1234,19 +1234,19 @@ do_open_popup( NactTreeView *view, GdkEventButton *event )
 }
 
 /*
- * nact_tree_view_select_row_at_path_by_string:
- * @view: this #NactTreeView object.
+ * fma_tree_view_select_row_at_path_by_string:
+ * @view: this #FMATreeView object.
  * @path: the #GtkTreePath to be selected.
  *
- * cf. nact_tree_view_select_row_at_path().
+ * cf. fma_tree_view_select_row_at_path().
  */
 static void
-select_row_at_path_by_string( NactTreeView *view, const gchar *path_str )
+select_row_at_path_by_string( FMATreeView *view, const gchar *path_str )
 {
        GtkTreePath *path;
 
        path = gtk_tree_path_new_from_string( path_str );
-       nact_tree_view_select_row_at_path( view, path );
+       fma_tree_view_select_row_at_path( view, path );
        gtk_tree_path_free( path );
 }
 
@@ -1254,7 +1254,7 @@ select_row_at_path_by_string( NactTreeView *view, const gchar *path_str )
  * Toggle or collapse the current subtree.
  */
 static void
-toggle_collapse( NactTreeView *view )
+toggle_collapse( FMATreeView *view )
 {
        guint toggle = TOGGLE_UNDEFINED;
 
@@ -1262,7 +1262,7 @@ toggle_collapse( NactTreeView *view )
 }
 
 static gboolean
-toggle_collapse_iter( NactTreeView *view, GtkTreeModel *model,
+toggle_collapse_iter( FMATreeView *view, GtkTreeModel *model,
                                                GtkTreeIter *iter, FMAObject *object, gpointer user_data )
 {
        guint count;
diff --git a/src/ui/fma-assistant-export.c b/src/ui/fma-assistant-export.c
index a6bced1..72debe0 100644
--- a/src/ui/fma-assistant-export.c
+++ b/src/ui/fma-assistant-export.c
@@ -46,7 +46,7 @@
 #include "fma-main-window.h"
 #include "fma-assistant-export.h"
 #include "fma-export-ask.h"
-#include "nact-tree-view.h"
+#include "fma-tree-view.h"
 
 /* Export Assistant
  *
@@ -73,7 +73,7 @@ enum {
  */
 struct _FMAAssistantExportPrivate {
        gboolean      dispose_has_run;
-       NactTreeView *items_view;
+       FMATreeView *items_view;
        gboolean      preferences_locked;
        gchar        *uri;
        GList        *selected_items;
@@ -404,15 +404,15 @@ items_tree_view_initialize_gtk( FMAAssistantExport *window, GtkAssistant *assist
        g_debug( "%s: window=%p, assistant=%p", thisfn, ( void * ) window, ( void * ) assistant );
 
        priv = window->private;
-       priv->items_view = nact_tree_view_new(
+       priv->items_view = fma_tree_view_new(
                        FMA_MAIN_WINDOW( base_window_get_main_window( BASE_WINDOW( window ))));
 
        parent = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( assistant ), "ActionsList" );
        g_return_if_fail( parent && GTK_IS_CONTAINER( parent ));
        gtk_container_add( GTK_CONTAINER( parent ), GTK_WIDGET( priv->items_view ));
 
-       nact_tree_view_set_mnemonic( priv->items_view, GTK_CONTAINER( assistant ), "ActionsListLabel" );
-       nact_tree_view_set_edition_mode( priv->items_view, TREE_MODE_SELECTION );
+       fma_tree_view_set_mnemonic( priv->items_view, GTK_CONTAINER( assistant ), "ActionsListLabel" );
+       fma_tree_view_set_edition_mode( priv->items_view, TREE_MODE_SELECTION );
 }
 
 static void
@@ -518,7 +518,7 @@ on_base_all_widgets_showed( FMAAssistantExport *window, void *empty )
        GtkAssistant *assistant;
        GtkWidget *page;
        GtkApplicationWindow *main_window;
-       NactTreeView *main_items_view;
+       FMATreeView *main_items_view;
        GList *items;
        GtkTreePath *path;
 
@@ -534,10 +534,10 @@ on_base_all_widgets_showed( FMAAssistantExport *window, void *empty )
                main_window = base_window_get_main_window( BASE_WINDOW( window ));
                g_return_if_fail( main_window && FMA_IS_MAIN_WINDOW( main_window ));
                main_items_view = fma_main_window_get_items_view( FMA_MAIN_WINDOW( main_window ));
-               items = nact_tree_view_get_items( main_items_view );
-               nact_tree_view_fill( window->private->items_view, items );
+               items = fma_tree_view_get_items( main_items_view );
+               fma_tree_view_fill( window->private->items_view, items );
 
                /* connect to the 'selection-changed' signal emitted by NactTreeView
                 */
                base_window_signal_connect(
                                BASE_WINDOW( window ),
@@ -548,7 +548,7 @@ on_base_all_widgets_showed( FMAAssistantExport *window, void *empty )
                /* select the first row
                 */
                path = gtk_tree_path_new_from_string( "0" );
-               nact_tree_view_select_row_at_path( window->private->items_view, path );
+               fma_tree_view_select_row_at_path( window->private->items_view, path );
                gtk_tree_path_free( path );
 
                page = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_ACTIONS_SELECTION );
@@ -534,10 +534,10 @@ on_base_all_widgets_showed( FMAAssistantExport *window, void *empty )
 
-               /* connect to the 'selection-changed' signal emitted by NactTreeView
+               /* connect to the 'selection-changed' signal emitted by FMATreeView
                 */
                base_window_signal_connect(
diff --git a/src/ui/fma-main-window.c b/src/ui/fma-main-window.c
index d880812..b323fcc 100644
--- a/src/ui/fma-main-window.c
+++ b/src/ui/fma-main-window.c
@@ -56,7 +56,7 @@
 #include "fma-main-window.h"
 #include "fma-menu.h"
 #include "fma-status-bar.h"
-#include "nact-tree-view.h"
+#include "fma-tree-view.h"
 #include "fma-confirm-logout.h"
 #include "fma-sort-buttons.h"
 
@@ -112,7 +112,7 @@ struct _FMAMainWindowPrivate {
        /**
         * Some convenience objects and data.
         */
-       NactTreeView      *items_view;
+       FMATreeView      *items_view;
        gboolean          is_tree_modified;
        FMAClipboard     *clipboard;
        FMAStatusBar     *statusbar;
@@ -174,8 +174,8 @@ static void       setup_main_ui( FMAMainWindow *main_window );
 static void       setup_treeview( FMAMainWindow *main_window );
 static void       setup_monitor_pivot( FMAMainWindow *main_window );
 static void       on_block_items_changed_timeout( FMAMainWindow *window );
-static void       on_tree_view_modified_status_changed( NactTreeView *treeview, gboolean is_modified, 
FMAMainWindow *window );
-static void       on_tree_view_selection_changed( NactTreeView *treeview, GList *selected_items, 
FMAMainWindow *window );
+static void       on_tree_view_modified_status_changed( FMATreeView *treeview, gboolean is_modified, 
FMAMainWindow *window );
+static void       on_tree_view_selection_changed( FMATreeView *treeview, GList *selected_items, 
FMAMainWindow *window );
 static void       on_tab_item_updated( FMAMainWindow *window, FMAIContext *context, guint data, void *empty 
);
 static void       raz_selection_properties( FMAMainWindow *window );
 static void       setup_current_selection( FMAMainWindow *window, FMAObjectId *selected_row );
@@ -767,14 +767,14 @@ setup_treeview( FMAMainWindow *main_window )
        GtkWidget *top_widget;
 
        priv = main_window->private;
-       priv->items_view = nact_tree_view_new( main_window );
+       priv->items_view = fma_tree_view_new( main_window );
 
        top_widget = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( main_window ), "ActionsList" );
        g_return_if_fail( top_widget && GTK_IS_CONTAINER( top_widget ));
        gtk_container_add( GTK_CONTAINER( top_widget ), GTK_WIDGET( priv->items_view ));
 
-       nact_tree_view_set_mnemonic( priv->items_view, GTK_CONTAINER( main_window ), "ActionsListLabel" );
-       nact_tree_view_set_edition_mode( priv->items_view, TREE_MODE_EDITION );
+       fma_tree_view_set_mnemonic( priv->items_view, GTK_CONTAINER( main_window ), "ActionsListLabel" );
+       fma_tree_view_set_edition_mode( priv->items_view, TREE_MODE_EDITION );
 
        g_signal_connect(
                        priv->items_view,
@@ -881,12 +881,12 @@ fma_main_window_get_statusbar( const FMAMainWindow *window )
  * fma_main_window_get_items_view:
  * @window: this #FMAMainWindow instance.
  *
  * Returns: The #NactTreeView convenience object.
  */
-NactTreeView *
+FMATreeView *
 fma_main_window_get_items_view( const FMAMainWindow *window )
 {
-       NactTreeView *view;
+       FMATreeView *view;
 
        g_return_val_if_fail( FMA_IS_MAIN_WINDOW( window ), NULL );
 
@@ -961,7 +961,7 @@ on_block_items_changed_timeout( FMAMainWindow *window )
  * the modification status of the items view has changed
  */
 static void
-on_tree_view_modified_status_changed( NactTreeView *treeview, gboolean is_modified, FMAMainWindow *window )
+on_tree_view_modified_status_changed( FMATreeView *treeview, gboolean is_modified, FMAMainWindow *window )
 {
        static const gchar *thisfn = "fma_main_window_on_tree_view_modified_status_changed";
 
@@ -979,7 +979,7 @@ on_tree_view_modified_status_changed( NactTreeView *treeview, gboolean is_modifi
  * tree view selection has changed
  */
 static void
-on_tree_view_selection_changed( NactTreeView *treeview, GList *selected_items, FMAMainWindow *window )
+on_tree_view_selection_changed( FMATreeView *treeview, GList *selected_items, FMAMainWindow *window )
 {
        static const gchar *thisfn = "fma_main_window_on_tree_view_selection_changed";
        guint count;
@@ -1209,7 +1209,7 @@ load_or_reload_items( FMAMainWindow *window )
 
        raz_selection_properties( window );
        tree = fma_updater_load_items( window->private->updater );
-       nact_tree_view_fill( window->private->items_view, tree );
+       fma_tree_view_fill( window->private->items_view, tree );
 
        g_debug( "%s: end of tree view filling", thisfn );
 }
@@ -881,12 +881,12 @@ fma_main_window_get_statusbar( const FMAMainWindow *window )
  * @window: this #FMAMainWindow instance.
  *
- * Returns: The #NactTreeView convenience object.
+ * Returns: The #FMATreeView convenience object.
  */
diff --git a/src/ui/fma-tree-ieditable.c b/src/ui/fma-tree-ieditable.c
index 1dadfa9..9559af1 100644
--- a/src/ui/fma-tree-ieditable.c
+++ b/src/ui/fma-tree-ieditable.c
@@ -42,7 +42,7 @@
 #include "fma-main-window.h"
 #include "fma-tree-ieditable.h"
 #include "fma-tree-model.h"
-#include "nact-tree-view.h"
+#include "fma-tree-view.h"
 
 /* private interface data
  */
@@ -50,7 +50,7 @@ struct _FMATreeIEditableInterfacePrivate {
        void *empty;                                            /* so that gcc -pedantic is happy */
 };
 
 /* data attached to the NactTreeView
  */
 typedef struct {
        FMAUpdater     *updater;
@@ -74,7 +74,7 @@ static GType          register_type( void );
 static void           interface_base_init( FMATreeIEditableInterface *klass );
 static void           interface_base_finalize( FMATreeIEditableInterface *klass );
 static gboolean       on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, FMATreeIEditable 
*instance );
-static void           on_label_edited( GtkCellRendererText *renderer, const gchar *path_str, const gchar 
*text, NactTreeView *items_view );
+static void           on_label_edited( GtkCellRendererText *renderer, const gchar *path_str, const gchar 
*text, FMATreeView *items_view );
 static void           on_tree_view_selection_changed( FMATreeIEditable *view, GList *selected_items, void 
*empty );
 static void           on_object_modified_status_changed( FMATreeIEditable *view, FMAObject *object, gboolean 
new_status, void *empty );
 static void           on_object_valid_status_changed( FMATreeIEditable *view, FMAObject *object, gboolean 
new_status, void *empty );
@@ -126,7 +126,7 @@ register_type( void )
 
        type = g_type_register_static( G_TYPE_INTERFACE, "FMATreeIEditable", &info, 0 );
 
-       g_type_interface_add_prerequisite( type, NACT_TYPE_TREE_VIEW );
+       g_type_interface_add_prerequisite( type, FMA_TYPE_TREE_VIEW );
 
        return( type );
 }
@@ -163,7 +163,7 @@ interface_base_finalize( FMATreeIEditableInterface *klass )
 
 /**
  * fma_tree_ieditable_initialize:
  * @instance: the #NactTreeView which implements this interface.
  * @treeview: the embedded #GtkTreeView tree view.
  * @window: the #BaseWindow which embeds the @instance.
  *
@@ -231,7 +231,7 @@ fma_tree_ieditable_initialize( FMATreeIEditable *instance, GtkTreeView *treeview
 
 /**
  * fma_tree_ieditable_terminate:
  * @instance: the #NactTreeView which implements this interface.
  *
  * Free the data when application quits.
  */
@@ -277,13 +277,13 @@ on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, FMATreeIEditable *i
  *   data = object_at_row + new_label
  */
 static void
-on_label_edited( GtkCellRendererText *renderer, const gchar *path_str, const gchar *text, NactTreeView 
*items_view )
+on_label_edited( GtkCellRendererText *renderer, const gchar *path_str, const gchar *text, FMATreeView 
*items_view )
 {
        IEditableData *ied;
        FMAObject *object;
        GtkTreePath *path;
 
-       if( nact_tree_view_are_notify_allowed( items_view )){
+       if( fma_tree_view_are_notify_allowed( items_view )){
                ied = ( IEditableData * ) g_object_get_data( G_OBJECT( items_view ), VIEW_DATA_IEDITABLE );
                path = gtk_tree_path_new_from_string( path_str );
                object = fma_tree_model_object_at_path( ied->model, path );
@@ -339,7 +339,7 @@ on_object_modified_status_changed( FMATreeIEditable *instance, FMAObject *object
                }
        }
 
-       if( nact_tree_view_are_notify_allowed( NACT_TREE_VIEW( instance ))){
+       if( fma_tree_view_are_notify_allowed( FMA_TREE_VIEW( instance ))){
                status = get_modification_status( ied );
                if( status != prev_status ){
                        g_signal_emit_by_name( instance, TREE_SIGNAL_MODIFIED_STATUS_CHANGED, status );
@@ -377,7 +377,7 @@ on_tree_view_level_zero_changed( FMATreeIEditable *view, gboolean is_modified, v
        prev_status = get_modification_status( ied );
        ied->level_zero_changed = is_modified;
 
-       if( nact_tree_view_are_notify_allowed( NACT_TREE_VIEW( view ))){
+       if( fma_tree_view_are_notify_allowed( FMA_TREE_VIEW( view ))){
                status = get_modification_status( ied );
                if( prev_status != status ){
                        g_signal_emit_by_name( view, TREE_SIGNAL_MODIFIED_STATUS_CHANGED, status );
@@ -437,7 +437,7 @@ fma_tree_ieditable_delete( FMATreeIEditable *instance, GList *items, TreeIEditab
        g_debug( "%s: instance=%p, items=%p (count=%d), ope=%u",
                        thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ), ope );
 
-       nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), FALSE );
+       fma_tree_view_set_notify_allowed( FMA_TREE_VIEW( instance ), FALSE );
        ied = get_instance_data( instance );
        prev_status = get_modification_status( ied );
 
@@ -473,11 +473,11 @@ fma_tree_ieditable_delete( FMATreeIEditable *instance, GList *items, TreeIEditab
 
        gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
 
-       nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), TRUE );
+       fma_tree_view_set_notify_allowed( FMA_TREE_VIEW( instance ), TRUE );
 
        if( path ){
                if( ope == TREE_OPE_DELETE ){
-                       nact_tree_view_select_row_at_path( NACT_TREE_VIEW( instance ), path );
+                       fma_tree_view_select_row_at_path( FMA_TREE_VIEW( instance ), path );
                }
                gtk_tree_path_free( path );
        }
@@ -720,7 +720,7 @@ fma_tree_ieditable_insert_at_path( FMATreeIEditable *instance, GList *items, Gtk
        g_debug( "%s: instance=%p, items=%p (count=%d)",
                thisfn, ( void * ) instance, ( void * ) items, g_list_length( items ));
 
-       nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), FALSE );
+       fma_tree_view_set_notify_allowed( FMA_TREE_VIEW( instance ), FALSE );
        ied = get_instance_data( instance );
        prev_status = get_modification_status( ied );
 
@@ -742,11 +742,11 @@ fma_tree_ieditable_insert_at_path( FMATreeIEditable *instance, GList *items, Gtk
        if( prev_status != status ){
                g_signal_emit_by_name( instance, TREE_SIGNAL_MODIFIED_STATUS_CHANGED, status );
        }
-       nact_tree_view_set_notify_allowed( NACT_TREE_VIEW( instance ), TRUE );
+       fma_tree_view_set_notify_allowed( FMA_TREE_VIEW( instance ), TRUE );
 
        increment_counters( instance, ied, items );
        gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
-       nact_tree_view_select_row_at_path( NACT_TREE_VIEW( instance ), actual_path );
+       fma_tree_view_select_row_at_path( FMA_TREE_VIEW( instance ), actual_path );
        gtk_tree_path_free( actual_path );
 }
 
@@ -795,7 +795,7 @@ fma_tree_ieditable_insert_into( FMATreeIEditable *instance, GList *items )
         */
        increment_counters( instance, ied, items );
        gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( ied->model ));
-       nact_tree_view_select_row_at_path( NACT_TREE_VIEW( instance ), new_path );
+       fma_tree_view_select_row_at_path( FMA_TREE_VIEW( instance ), new_path );
        gtk_tree_path_free( new_path );
        gtk_tree_path_free( insert_path );
 }
@@ -948,7 +948,7 @@ fma_tree_ieditable_set_items( FMATreeIEditable *instance, GList *items )
                new_item = FMA_OBJECT_ITEM( it->data );
 
                id = fma_object_get_id( new_item );
-               old_item = nact_tree_view_get_item_by_id( NACT_TREE_VIEW( instance ), id );
+               old_item = fma_tree_view_get_item_by_id( FMA_TREE_VIEW( instance ), id );
 
                if( !old_item ){
                        g_warning( "%s: id=%s: item not found - ignored", thisfn, id );
@@ -1040,7 +1040,7 @@ check_level_zero_status( FMATreeIEditable *instance )
        items = fma_pivot_get_items( FMA_PIVOT( ied->updater ));
        pivot_str = get_items_id_list_str( items );
 
-       items = nact_tree_view_get_items( NACT_TREE_VIEW( instance ));
+       items = fma_tree_view_get_items( FMA_TREE_VIEW( instance ));
        view_str = get_items_id_list_str( items );
        fma_object_free_items( items );
 
@@ -50,7 +50,7 @@ struct _FMATreeIEditableInterfacePrivate {
 };
 
-/* data attached to the NactTreeView
+/* data attached to the FMATreeView
  */
 typedef struct {
@@ -163,7 +163,7 @@ interface_base_finalize( FMATreeIEditableInterface *klass )
 /**
  * fma_tree_ieditable_initialize:
- * @instance: the #NactTreeView which implements this interface.
+ * @instance: the #FMATreeView which implements this interface.
  * @treeview: the embedded #GtkTreeView tree view.
  * @window: the #BaseWindow which embeds the @instance.
@@ -231,7 +231,7 @@ fma_tree_ieditable_initialize( FMATreeIEditable *instance, GtkTreeView *treeview
 /**
  * fma_tree_ieditable_terminate:
- * @instance: the #NactTreeView which implements this interface.
+ * @instance: the #FMATreeView which implements this interface.
  *
  * Free the data when application quits.
diff --git a/src/ui/nact-tree-view.h b/src/ui/fma-tree-view.h
similarity index 53%
rename from src/ui/nact-tree-view.h
rename to src/ui/fma-tree-view.h
index 6b630c1..9fb9d9c 100644
--- a/src/ui/nact-tree-view.h
+++ b/src/ui/fma-tree-view.h
@@ -27,23 +27,23 @@
  *   ... and many others (see AUTHORS)
  */
 
-#ifndef __UI_NACT_TREE_VIEW_H__
-#define __UI_NACT_TREE_VIEW_H__
+#ifndef __UI_FMA_TREE_VIEW_H__
+#define __UI_FMA_TREE_VIEW_H__
 
 /*
- * SECTION: nact-tree-view
- * @title: NactTreeView
+ * SECTION: fma-tree-view
+ * @title: FMATreeView
  * @short_description: The Tree View Base Class Definition
- * @include: nact-tree-view.h
+ * @include: ui/fma-tree-view.h
  *
  * This is a convenience class to manage a read-only items tree view.
  *
  * The NactTreeView encapsulates the GtkTreeView which displays the items
  * list on the left of the main pane.
  *
  * It is instanciated from FMAMainWindow::on_initialize_gtk().
  *
  * A pointer to this NactTreeView is attached to the FMAMainWindow at
  * construction time.
  */
 
@@ -54,30 +54,30 @@
 
 G_BEGIN_DECLS
 
-#define NACT_TYPE_TREE_VIEW                ( nact_tree_view_get_type())
-#define NACT_TREE_VIEW( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, NACT_TYPE_TREE_VIEW, 
NactTreeView ))
-#define NACT_TREE_VIEW_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, NACT_TYPE_TREE_VIEW, 
NactTreeViewClass ))
-#define NACT_IS_TREE_VIEW( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, NACT_TYPE_TREE_VIEW ))
-#define NACT_IS_TREE_VIEW_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), NACT_TYPE_TREE_VIEW ))
-#define NACT_TREE_VIEW_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), NACT_TYPE_TREE_VIEW, 
NactTreeViewClass ))
+#define FMA_TYPE_TREE_VIEW                ( fma_tree_view_get_type())
+#define FMA_TREE_VIEW( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, FMA_TYPE_TREE_VIEW, 
FMATreeView ))
+#define FMA_TREE_VIEW_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, FMA_TYPE_TREE_VIEW, 
FMATreeViewClass ))
+#define FMA_IS_TREE_VIEW( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, FMA_TYPE_TREE_VIEW ))
+#define FMA_IS_TREE_VIEW_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), FMA_TYPE_TREE_VIEW ))
+#define FMA_TREE_VIEW_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), FMA_TYPE_TREE_VIEW, 
FMATreeViewClass ))
 
-typedef struct _NactTreeViewPrivate        NactTreeViewPrivate;
+typedef struct _FMATreeViewPrivate        FMATreeViewPrivate;
 
 typedef struct {
        /*< private >*/
-       GtkBin               parent;
-       NactTreeViewPrivate *private;
+       GtkBin              parent;
+       FMATreeViewPrivate *private;
 }
-       NactTreeView;
+       FMATreeView;
 
 typedef struct {
        /*< private >*/
-       GtkBinClass          parent;
+       GtkBinClass         parent;
 }
-       NactTreeViewClass;
+       FMATreeViewClass;
 
 /**
  * Signals emitted by the NactTreeView instance.
  */
 #define TREE_SIGNAL_COUNT_CHANGED                              "tree-signal-count-changed"
 #define TREE_SIGNAL_FOCUS_IN                                   "tree-signal-focus-in"
@@ -105,30 +105,30 @@ enum {
        TREE_LIST_DELETED  = 1<<8,
 };
 
-GType         nact_tree_view_get_type( void );
+GType          fma_tree_view_get_type          ( void );
 
-NactTreeView *nact_tree_view_new               ( FMAMainWindow *main_window );
+FMATreeView   *fma_tree_view_new               ( FMAMainWindow *main_window );
 
-void          nact_tree_view_set_mnemonic      ( NactTreeView *view,
+void           fma_tree_view_set_mnemonic      ( FMATreeView *view,
                                                                                                              
  GtkContainer *parent,
                                                                                                              
  const gchar *widget_name );
 
-void          nact_tree_view_set_edition_mode  ( NactTreeView *view,
+void           fma_tree_view_set_edition_mode  ( FMATreeView *view,
                                                                                                              
  NactTreeMode mode );
 
-void          nact_tree_view_fill              ( NactTreeView *view, GList *items );
+void           fma_tree_view_fill              ( FMATreeView *view, GList *items );
 
-gboolean      nact_tree_view_are_notify_allowed( const NactTreeView *view );
-void          nact_tree_view_set_notify_allowed( NactTreeView *view, gboolean allow );
+gboolean       fma_tree_view_are_notify_allowed( const FMATreeView *view );
+void           fma_tree_view_set_notify_allowed( FMATreeView *view, gboolean allow );
 
-void          nact_tree_view_collapse_all      ( const NactTreeView *view );
-void          nact_tree_view_expand_all        ( const NactTreeView *view );
-FMAObjectItem *nact_tree_view_get_item_by_id    ( const NactTreeView *view, const gchar *id );
-GList        *nact_tree_view_get_items         ( const NactTreeView *view );
-GList        *nact_tree_view_get_items_ex      ( const NactTreeView *view, guint mode );
+void           fma_tree_view_collapse_all      ( const FMATreeView *view );
+void           fma_tree_view_expand_all        ( const FMATreeView *view );
+FMAObjectItem *fma_tree_view_get_item_by_id    ( const FMATreeView *view, const gchar *id );
+GList         *fma_tree_view_get_items         ( const FMATreeView *view );
+GList         *fma_tree_view_get_items_ex      ( const FMATreeView *view, guint mode );
 
-void          nact_tree_view_select_row_at_path( NactTreeView *view, GtkTreePath *path );
+void           fma_tree_view_select_row_at_path( FMATreeView *view, GtkTreePath *path );
 
 G_END_DECLS
 
-#endif /* __UI_NACT_TREE_VIEW_H__ */
+#endif /* __UI_FMA_TREE_VIEW_H__ */
@@ -27,23 +27,23 @@
  * This is a convenience class to manage a read-only items tree view.
  *
- * The NactTreeView encapsulates the GtkTreeView which displays the items
+ * The FMATreeView encapsulates the GtkTreeView which displays the items
  * list on the left of the main pane.
  *
@@ -27,23 +27,23 @@
  * It is instanciated from FMAMainWindow::on_initialize_gtk().
  *
- * A pointer to this NactTreeView is attached to the FMAMainWindow at
+ * A pointer to this FMATreeView is attached to the FMAMainWindow at
  * construction time.
  */
@@ -54,30 +54,30 @@
 
 /**
- * Signals emitted by the NactTreeView instance.
+ * Signals emitted by the FMATreeView instance.
  */
 #define TREE_SIGNAL_COUNT_CHANGED                              "tree-signal-count-changed"



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]